@@ -3,8 +3,9 @@ Main interface for robomaker service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.robomaker import (
+    from mypy_boto3_robomaker import (
         Client,
         ListDeploymentJobsPaginator,
         ListFleetsPaginator,
@@ -14,7 +15,7 @@ Usage::
         ListSimulationJobBatchesPaginator,
         ListSimulationJobsPaginator,
         RoboMakerClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -28,6 +29,7 @@ Usage::
     list_simulation_applications_paginator: ListSimulationApplicationsPaginator = client.get_paginator("list_simulation_applications")
     list_simulation_job_batches_paginator: ListSimulationJobBatchesPaginator = client.get_paginator("list_simulation_job_batches")
     list_simulation_jobs_paginator: ListSimulationJobsPaginator = client.get_paginator("list_simulation_jobs")
+    ```
 """
 from mypy_boto3_robomaker.client import RoboMakerClient as Client, RoboMakerClient
 from mypy_boto3_robomaker.paginator import (
