@@ -3,13 +3,15 @@ Main interface for robomaker service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.robomaker import RoboMakerClient
+    from mypy_boto3_robomaker import RoboMakerClient
 
     session = boto3.Session()
 
     client: RoboMakerClient = boto3.client("robomaker")
     session_client: RoboMakerClient = session.client("robomaker")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -97,7 +99,7 @@ class Exceptions:
 
 class RoboMakerClient:
     """
-    [RoboMaker.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client)
+    [RoboMaker.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client)
     """
 
     exceptions: Exceptions
@@ -106,44 +108,44 @@ class RoboMakerClient:
         self, jobs: List[str]
     ) -> BatchDescribeSimulationJobResponseTypeDef:
         """
-        [Client.batch_describe_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.batch_describe_simulation_job)
+        [Client.batch_describe_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.batch_describe_simulation_job)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.can_paginate)
         """
 
     def cancel_deployment_job(self, job: str) -> Dict[str, Any]:
         """
-        [Client.cancel_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.cancel_deployment_job)
+        [Client.cancel_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.cancel_deployment_job)
         """
 
     def cancel_simulation_job(self, job: str) -> Dict[str, Any]:
         """
-        [Client.cancel_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.cancel_simulation_job)
+        [Client.cancel_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.cancel_simulation_job)
         """
 
     def cancel_simulation_job_batch(self, batch: str) -> Dict[str, Any]:
         """
-        [Client.cancel_simulation_job_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.cancel_simulation_job_batch)
+        [Client.cancel_simulation_job_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.cancel_simulation_job_batch)
         """
 
     def create_deployment_job(
         self,
         clientRequestToken: str,
         fleet: str,
-        deploymentApplicationConfigs: List[DeploymentApplicationConfigTypeDef],
-        deploymentConfig: DeploymentConfigTypeDef = None,
+        deploymentApplicationConfigs: List["DeploymentApplicationConfigTypeDef"],
+        deploymentConfig: "DeploymentConfigTypeDef" = None,
         tags: Dict[str, str] = None,
     ) -> CreateDeploymentJobResponseTypeDef:
         """
-        [Client.create_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_deployment_job)
+        [Client.create_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_deployment_job)
         """
 
     def create_fleet(self, name: str, tags: Dict[str, str] = None) -> CreateFleetResponseTypeDef:
         """
-        [Client.create_fleet documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_fleet)
+        [Client.create_fleet documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_fleet)
         """
 
     def create_robot(
@@ -154,45 +156,45 @@ class RoboMakerClient:
         tags: Dict[str, str] = None,
     ) -> CreateRobotResponseTypeDef:
         """
-        [Client.create_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_robot)
+        [Client.create_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_robot)
         """
 
     def create_robot_application(
         self,
         name: str,
         sources: List[SourceConfigTypeDef],
-        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
+        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
         tags: Dict[str, str] = None,
     ) -> CreateRobotApplicationResponseTypeDef:
         """
-        [Client.create_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_robot_application)
+        [Client.create_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_robot_application)
         """
 
     def create_robot_application_version(
         self, application: str, currentRevisionId: str = None
     ) -> CreateRobotApplicationVersionResponseTypeDef:
         """
-        [Client.create_robot_application_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_robot_application_version)
+        [Client.create_robot_application_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_robot_application_version)
         """
 
     def create_simulation_application(
         self,
         name: str,
         sources: List[SourceConfigTypeDef],
-        simulationSoftwareSuite: SimulationSoftwareSuiteTypeDef,
-        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
-        renderingEngine: RenderingEngineTypeDef = None,
+        simulationSoftwareSuite: "SimulationSoftwareSuiteTypeDef",
+        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
+        renderingEngine: "RenderingEngineTypeDef" = None,
         tags: Dict[str, str] = None,
     ) -> CreateSimulationApplicationResponseTypeDef:
         """
-        [Client.create_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_simulation_application)
+        [Client.create_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_simulation_application)
         """
 
     def create_simulation_application_version(
         self, application: str, currentRevisionId: str = None
     ) -> CreateSimulationApplicationVersionResponseTypeDef:
         """
-        [Client.create_simulation_application_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_simulation_application_version)
+        [Client.create_simulation_application_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_simulation_application_version)
         """
 
     def create_simulation_job(
@@ -200,88 +202,88 @@ class RoboMakerClient:
         maxJobDurationInSeconds: int,
         iamRole: str,
         clientRequestToken: str = None,
-        outputLocation: OutputLocationTypeDef = None,
-        loggingConfig: LoggingConfigTypeDef = None,
+        outputLocation: "OutputLocationTypeDef" = None,
+        loggingConfig: "LoggingConfigTypeDef" = None,
         failureBehavior: Literal["Fail", "Continue"] = None,
-        robotApplications: List[RobotApplicationConfigTypeDef] = None,
-        simulationApplications: List[SimulationApplicationConfigTypeDef] = None,
-        dataSources: List[DataSourceConfigTypeDef] = None,
+        robotApplications: List["RobotApplicationConfigTypeDef"] = None,
+        simulationApplications: List["SimulationApplicationConfigTypeDef"] = None,
+        dataSources: List["DataSourceConfigTypeDef"] = None,
         tags: Dict[str, str] = None,
-        vpcConfig: VPCConfigTypeDef = None,
-        compute: ComputeTypeDef = None,
+        vpcConfig: "VPCConfigTypeDef" = None,
+        compute: "ComputeTypeDef" = None,
     ) -> CreateSimulationJobResponseTypeDef:
         """
-        [Client.create_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.create_simulation_job)
+        [Client.create_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.create_simulation_job)
         """
 
     def delete_fleet(self, fleet: str) -> Dict[str, Any]:
         """
-        [Client.delete_fleet documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.delete_fleet)
+        [Client.delete_fleet documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.delete_fleet)
         """
 
     def delete_robot(self, robot: str) -> Dict[str, Any]:
         """
-        [Client.delete_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.delete_robot)
+        [Client.delete_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.delete_robot)
         """
 
     def delete_robot_application(
         self, application: str, applicationVersion: str = None
     ) -> Dict[str, Any]:
         """
-        [Client.delete_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.delete_robot_application)
+        [Client.delete_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.delete_robot_application)
         """
 
     def delete_simulation_application(
         self, application: str, applicationVersion: str = None
     ) -> Dict[str, Any]:
         """
-        [Client.delete_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.delete_simulation_application)
+        [Client.delete_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.delete_simulation_application)
         """
 
     def deregister_robot(self, fleet: str, robot: str) -> DeregisterRobotResponseTypeDef:
         """
-        [Client.deregister_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.deregister_robot)
+        [Client.deregister_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.deregister_robot)
         """
 
     def describe_deployment_job(self, job: str) -> DescribeDeploymentJobResponseTypeDef:
         """
-        [Client.describe_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_deployment_job)
+        [Client.describe_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_deployment_job)
         """
 
     def describe_fleet(self, fleet: str) -> DescribeFleetResponseTypeDef:
         """
-        [Client.describe_fleet documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_fleet)
+        [Client.describe_fleet documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_fleet)
         """
 
     def describe_robot(self, robot: str) -> DescribeRobotResponseTypeDef:
         """
-        [Client.describe_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_robot)
+        [Client.describe_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_robot)
         """
 
     def describe_robot_application(
         self, application: str, applicationVersion: str = None
     ) -> DescribeRobotApplicationResponseTypeDef:
         """
-        [Client.describe_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_robot_application)
+        [Client.describe_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_robot_application)
         """
 
     def describe_simulation_application(
         self, application: str, applicationVersion: str = None
     ) -> DescribeSimulationApplicationResponseTypeDef:
         """
-        [Client.describe_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_simulation_application)
+        [Client.describe_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_simulation_application)
         """
 
     def describe_simulation_job(self, job: str) -> DescribeSimulationJobResponseTypeDef:
         """
-        [Client.describe_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_simulation_job)
+        [Client.describe_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_simulation_job)
         """
 
     def describe_simulation_job_batch(
         self, batch: str
     ) -> DescribeSimulationJobBatchResponseTypeDef:
         """
-        [Client.describe_simulation_job_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.describe_simulation_job_batch)
+        [Client.describe_simulation_job_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.describe_simulation_job_batch)
         """
 
     def generate_presigned_url(
@@ -292,21 +294,21 @@ class RoboMakerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.generate_presigned_url)
         """
 
     def list_deployment_jobs(
         self, filters: List[FilterTypeDef] = None, nextToken: str = None, maxResults: int = None
     ) -> ListDeploymentJobsResponseTypeDef:
         """
-        [Client.list_deployment_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_deployment_jobs)
+        [Client.list_deployment_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_deployment_jobs)
         """
 
     def list_fleets(
         self, nextToken: str = None, maxResults: int = None, filters: List[FilterTypeDef] = None
     ) -> ListFleetsResponseTypeDef:
         """
-        [Client.list_fleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_fleets)
+        [Client.list_fleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_fleets)
         """
 
     def list_robot_applications(
@@ -317,14 +319,14 @@ class RoboMakerClient:
         filters: List[FilterTypeDef] = None,
     ) -> ListRobotApplicationsResponseTypeDef:
         """
-        [Client.list_robot_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_robot_applications)
+        [Client.list_robot_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_robot_applications)
         """
 
     def list_robots(
         self, nextToken: str = None, maxResults: int = None, filters: List[FilterTypeDef] = None
     ) -> ListRobotsResponseTypeDef:
         """
-        [Client.list_robots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_robots)
+        [Client.list_robots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_robots)
         """
 
     def list_simulation_applications(
@@ -335,88 +337,88 @@ class RoboMakerClient:
         filters: List[FilterTypeDef] = None,
     ) -> ListSimulationApplicationsResponseTypeDef:
         """
-        [Client.list_simulation_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_simulation_applications)
+        [Client.list_simulation_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_simulation_applications)
         """
 
     def list_simulation_job_batches(
         self, nextToken: str = None, maxResults: int = None, filters: List[FilterTypeDef] = None
     ) -> ListSimulationJobBatchesResponseTypeDef:
         """
-        [Client.list_simulation_job_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_simulation_job_batches)
+        [Client.list_simulation_job_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_simulation_job_batches)
         """
 
     def list_simulation_jobs(
         self, nextToken: str = None, maxResults: int = None, filters: List[FilterTypeDef] = None
     ) -> ListSimulationJobsResponseTypeDef:
         """
-        [Client.list_simulation_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_simulation_jobs)
+        [Client.list_simulation_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_simulation_jobs)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.list_tags_for_resource)
         """
 
     def register_robot(self, fleet: str, robot: str) -> RegisterRobotResponseTypeDef:
         """
-        [Client.register_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.register_robot)
+        [Client.register_robot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.register_robot)
         """
 
     def restart_simulation_job(self, job: str) -> Dict[str, Any]:
         """
-        [Client.restart_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.restart_simulation_job)
+        [Client.restart_simulation_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.restart_simulation_job)
         """
 
     def start_simulation_job_batch(
         self,
-        createSimulationJobRequests: List[SimulationJobRequestTypeDef],
+        createSimulationJobRequests: List["SimulationJobRequestTypeDef"],
         clientRequestToken: str = None,
-        batchPolicy: BatchPolicyTypeDef = None,
+        batchPolicy: "BatchPolicyTypeDef" = None,
         tags: Dict[str, str] = None,
     ) -> StartSimulationJobBatchResponseTypeDef:
         """
-        [Client.start_simulation_job_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.start_simulation_job_batch)
+        [Client.start_simulation_job_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.start_simulation_job_batch)
         """
 
     def sync_deployment_job(
         self, clientRequestToken: str, fleet: str
     ) -> SyncDeploymentJobResponseTypeDef:
         """
-        [Client.sync_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.sync_deployment_job)
+        [Client.sync_deployment_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.sync_deployment_job)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.untag_resource)
         """
 
     def update_robot_application(
         self,
         application: str,
         sources: List[SourceConfigTypeDef],
-        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
+        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
         currentRevisionId: str = None,
     ) -> UpdateRobotApplicationResponseTypeDef:
         """
-        [Client.update_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.update_robot_application)
+        [Client.update_robot_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.update_robot_application)
         """
 
     def update_simulation_application(
         self,
         application: str,
         sources: List[SourceConfigTypeDef],
-        simulationSoftwareSuite: SimulationSoftwareSuiteTypeDef,
-        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
-        renderingEngine: RenderingEngineTypeDef = None,
+        simulationSoftwareSuite: "SimulationSoftwareSuiteTypeDef",
+        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
+        renderingEngine: "RenderingEngineTypeDef" = None,
         currentRevisionId: str = None,
     ) -> UpdateSimulationApplicationResponseTypeDef:
         """
-        [Client.update_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Client.update_simulation_application)
+        [Client.update_simulation_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Client.update_simulation_application)
         """
 
     @overload
@@ -424,13 +426,13 @@ class RoboMakerClient:
         self, operation_name: Literal["list_deployment_jobs"]
     ) -> ListDeploymentJobsPaginator:
         """
-        [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
+        [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_fleets"]) -> ListFleetsPaginator:
         """
-        [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
+        [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
         """
 
     @overload
@@ -438,13 +440,13 @@ class RoboMakerClient:
         self, operation_name: Literal["list_robot_applications"]
     ) -> ListRobotApplicationsPaginator:
         """
-        [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
+        [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_robots"]) -> ListRobotsPaginator:
         """
-        [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
+        [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
         """
 
     @overload
@@ -452,7 +454,7 @@ class RoboMakerClient:
         self, operation_name: Literal["list_simulation_applications"]
     ) -> ListSimulationApplicationsPaginator:
         """
-        [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
+        [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
         """
 
     @overload
@@ -460,7 +462,7 @@ class RoboMakerClient:
         self, operation_name: Literal["list_simulation_job_batches"]
     ) -> ListSimulationJobBatchesPaginator:
         """
-        [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
+        [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
         """
 
     @overload
@@ -468,5 +470,5 @@ class RoboMakerClient:
         self, operation_name: Literal["list_simulation_jobs"]
     ) -> ListSimulationJobsPaginator:
         """
-        [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
+        [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
         """
