@@ -3,8 +3,11 @@ Main interface for robomaker service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.robomaker import (
+
+    from mypy_boto3_robomaker import RoboMakerClient
+    from mypy_boto3_robomaker import (
         ListDeploymentJobsPaginator,
         ListFleetsPaginator,
         ListRobotApplicationsPaginator,
@@ -23,6 +26,7 @@ Usage::
     list_simulation_applications_paginator: ListSimulationApplicationsPaginator = client.get_paginator("list_simulation_applications")
     list_simulation_job_batches_paginator: ListSimulationJobBatchesPaginator = client.get_paginator("list_simulation_job_batches")
     list_simulation_jobs_paginator: ListSimulationJobsPaginator = client.get_paginator("list_simulation_jobs")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, List, TYPE_CHECKING
@@ -53,33 +57,33 @@ __all__ = (
 
 class ListDeploymentJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
+    [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDeploymentJobsResponseTypeDef]:
         """
-        [ListDeploymentJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
+        [ListDeploymentJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
         """
 
 
 class ListFleetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
+    [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListFleetsResponseTypeDef]:
         """
-        [ListFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
+        [ListFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
         """
 
 
 class ListRobotApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
+    [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
     """
 
     def paginate(
@@ -89,26 +93,26 @@ class ListRobotApplicationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRobotApplicationsResponseTypeDef]:
         """
-        [ListRobotApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
+        [ListRobotApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
         """
 
 
 class ListRobotsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
+    [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListRobotsResponseTypeDef]:
         """
-        [ListRobots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
+        [ListRobots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
         """
 
 
 class ListSimulationApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
+    [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
     """
 
     def paginate(
@@ -118,31 +122,31 @@ class ListSimulationApplicationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSimulationApplicationsResponseTypeDef]:
         """
-        [ListSimulationApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
+        [ListSimulationApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
         """
 
 
 class ListSimulationJobBatchesPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
+    [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSimulationJobBatchesResponseTypeDef]:
         """
-        [ListSimulationJobBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
+        [ListSimulationJobBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
         """
 
 
 class ListSimulationJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
+    [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSimulationJobsResponseTypeDef]:
         """
-        [ListSimulationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
+        [ListSimulationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
         """
